@@ -1,16 +1,16 @@
 use strict;
 use warnings;
-
+use FindBin qw($Bin);   
+BEGIN {
+   unshift @INC, "$Bin/blib/lib" ; 
+   unshift @INC, "$Bin/t/data";  
+};
 #
 #  for those Test::Harness lovers out there
 #
 use Test::Harness;
-use File::Basename;
+  
  
-BEGIN {
-   unshift @INC, dirname(dirname($0)) . '/t/lib';
-   unshift @INC, dirname(dirname($0)) . '/t/data';
-};
  
 
 if ($ARGV[0] && $ARGV[0] eq '-v') {
@@ -18,5 +18,6 @@ if ($ARGV[0] && $ARGV[0] eq '-v') {
   shift @ARGV;
 }
 
-my $test_dir = dirname($0) . '/t';
+my $test_dir =  $Bin . '/t';
+Test::Harness::runtests(<$test_dir/*.t>);
 Test::Harness::runtests(<$test_dir/data/t/*.t>);
